==> Paws-0.33.tar.gz: Paws-0.33/lib/Paws/Greengrass/DefinitionInformation.pm <==
package Paws::Greengrass::DefinitionInformation;
  use Moose;
  has Arn => (is => 'ro', isa => 'Str');
  has CreationTimestamp => (is => 'ro', isa => 'Str');
  has Id => (is => 'ro', isa => 'Str');
  has LastUpdatedTimestamp => (is => 'ro', isa => 'Str');
  has LatestVersion => (is => 'ro', isa => 'Str');
  has LatestVersionArn => (is => 'ro', isa => 'Str');
  has Name => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Greengrass::DefinitionInformation

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::Greengrass::DefinitionInformation object:

  $service_obj->Method(Att1 => { Arn => $value, ..., Name => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::Greengrass::DefinitionInformation object:

  $result = $service_obj->Method(...);
  $result->Att1->Arn

=head1 DESCRIPTION

Information on the Definition

=head1 ATTRIBUTES


=head2 Arn => Str

  Arn of the definition.


=head2 CreationTimestamp => Str

  Timestamp of when the definition was created.


=head2 Id => Str

  Id of the definition.


=head2 LastUpdatedTimestamp => Str

  Last updated timestamp of the definition.


=head2 LatestVersion => Str

  Last version of the definition.


=head2 LatestVersionArn => Str

  Latest version arn of the definition.


=head2 Name => Str

  Name of the definition.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::Greengrass>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.39.tar.gz: Paws-0.39/lib/Paws/Greengrass/DefinitionInformation.pm <==
package Paws::Greengrass::DefinitionInformation;
  use Moose;
  has Arn => (is => 'ro', isa => 'Str');
  has CreationTimestamp => (is => 'ro', isa => 'Str');
  has Id => (is => 'ro', isa => 'Str');
  has LastUpdatedTimestamp => (is => 'ro', isa => 'Str');
  has LatestVersion => (is => 'ro', isa => 'Str');
  has LatestVersionArn => (is => 'ro', isa => 'Str');
  has Name => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Greengrass::DefinitionInformation

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::Greengrass::DefinitionInformation object:

  $service_obj->Method(Att1 => { Arn => $value, ..., Name => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::Greengrass::DefinitionInformation object:

  $result = $service_obj->Method(...);
  $result->Att1->Arn

=head1 DESCRIPTION

Information about a definition.

=head1 ATTRIBUTES


=head2 Arn => Str

  The ARN of the definition.


=head2 CreationTimestamp => Str

  The time, in milliseconds since the epoch, when the definition was
created.


=head2 Id => Str

  The ID of the definition.


=head2 LastUpdatedTimestamp => Str

  The time, in milliseconds since the epoch, when the definition was last
updated.


=head2 LatestVersion => Str

  The latest version of the definition.


=head2 LatestVersionArn => Str

  The ARN of the latest version of the definition.


=head2 Name => Str

  The name of the definition.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::Greengrass>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
